Architecture Documentation
===========================

Architecture Decision Records
------------------------------

This section documents significant architectural decisions made in the NLSQ project.

.. toctree::
   :maxdepth: 1
   :caption: Decision Records

   adr/README
   adr/003-streaming-over-subsampling
   adr/004-parameter-unpacking-simplification
   adr/005-jax-autodiff-gradients
